@@ -5,9 +5,11 @@ http://code.google.com/p/django-values/
 from decimal import Decimal
 from django import forms
 from django.core.exceptions import ImproperlyConfigured
+from django.db import connection, DatabaseError
 from django.utils import simplejson
 from django.utils.datastructures import SortedDict
 from django.utils.encoding import smart_str
+from django.utils.safestring import mark_safe
 from django.utils.translation import gettext, ugettext_lazy as _
 from livesettings.models import find_setting, LongSetting, Setting, SettingNotSet
 from livesettings.overrides import get_overrides
@@ -18,12 +20,21 @@ import signals
 
 __all__ = ['BASE_GROUP', 'ConfigurationGroup', 'Value', 'BooleanValue', 'DecimalValue', 'DurationValue',
       'FloatValue', 'IntegerValue', 'ModuleValue', 'PercentValue', 'PositiveIntegerValue', 'SortedDotDict',
-      'StringValue', 'LongStringValue', 'MultipleStringValue', 'LongMultipleStringValue']
+      'StringValue', 'LongStringValue', 'MultipleStringValue', 'LongMultipleStringValue', 'PasswordValue']
 
 _WARN = {}
+try:
+    is_setting_initializing
+except:
+    is_setting_initializing = True  # until the first success find "livesettings_setting" table, by any thread
+
 
 log = logging.getLogger('configuration')
 
+# The constant NOTSET is a placeholder for an uninitialized value (which has no
+# default in the user's application and no value in the database).
+# It is different from None or "" which are result of an empty field in the form.
+# It leads to to the existing more complicated code of Values classes, hopefully more robust.
 NOTSET = object()
 
 class SortedDotDict(SortedDict):
@@ -122,7 +133,7 @@ class Value(object):
             - `requires` - If given as a `Value`, then this field will only be rendered if that Value evaluates true (for Boolean requires) or the proper key is in the associated value.
             - `requiresvalue` - If set, then this field will only be rendered if that value is in the list returned by self.value. Defaults to self.key.
             - `hidden` - If true, then render a hidden field.
-            - `default` - If given, then this Value will return that default whenever it has no assocated `Setting`.
+            - `default` - If given, then this Value will return that default whenever it has no associated `Setting`.
             - `update_callback` - if given, then this value will call the callback whenever updated
         """
         self.group = group
@@ -262,6 +273,7 @@ class Value(object):
     setting = property(fget = _setting)
 
     def _value(self):
+        global is_setting_initializing
         use_db, overrides = get_overrides()
 
         if not use_db:
@@ -278,6 +290,7 @@ class Value(object):
                 val = self.setting.value
 
             except SettingNotSet, sns:
+                is_setting_initializing = False
                 if self.use_default:
                     val = self.default
                     if overrides:
@@ -289,27 +302,32 @@ class Value(object):
                     val = NOTSET
 
             except AttributeError, ae:
+                is_setting_initializing = False
                 log.error("Attribute error: %s", ae)
                 log.error("%s: Could not get _value of %s", self.key, self.setting)
                 raise(ae)
 
             except Exception, e:
                 global _WARN
-                log.error(e)
-                if str(e).find("configuration_setting") > -1:
-                    if not _WARN.has_key('configuration_setting'):
-                        log.warn('Error loading setting %s.%s from table, OK if you are in syncdb', self.group.key, self.key)
-                        _WARN['configuration_setting'] = True
+                if is_setting_initializing and isinstance(e, DatabaseError) and str(e).find("livesettings_setting") > -1:
+                    if not _WARN.has_key('livesettings_setting'):
+                        log.warn(str(e).strip())
+                        _WARN['livesettings_setting'] = True
+                    log.warn('Error loading livesettings from table, OK if you are in syncdb or before it. ROLLBACK')
+                    connection._rollback()
 
                     if self.use_default:
                         val = self.default
                     else:
                         raise ImproperlyConfigured("All settings used in startup must have defaults, %s.%s does not", self.group.key, self.key)
                 else:
+                    is_setting_initializing = False
                     import traceback
                     traceback.print_exc()
-                    log.warn("Problem finding settings %s.%s, %s", self.group.key, self.key, e)
+                    log.error("Problem finding settings %s.%s, %s", self.group.key, self.key, e)
                     raise SettingNotSet("Startup error, couldn't load %s.%s" %(self.group.key, self.key))
+            else:
+                is_setting_initializing = False
         return val
 
     def update(self, value):
@@ -332,7 +350,7 @@ class Value(object):
                 except SettingNotSet:
                     s = self.make_setting(db_value)
 
-                if self.use_default and self.default == new_value:
+                if self.use_default and self.to_python(self.default) == self.to_python(new_value):
                     if s.id:
                         log.info("Deleted setting %s.%s", self.group.key, self.key)
                         s.delete()
@@ -375,7 +393,7 @@ class Value(object):
     def to_editor(self, value):
         "Returns a value suitable for display in a form widget"
         if value == NOTSET:
-            return NOTSET
+            return NOTSET  # TODO this was not a good idea for an editor: "<object object 0x123..>"
         return unicode(value)
 
 ###############
@@ -404,12 +422,19 @@ class BooleanValue(Value):
 class DecimalValue(Value):
     class field(forms.DecimalField):
 
-           def __init__(self, *args, **kwargs):
-               kwargs['required'] = False
-               forms.DecimalField.__init__(self, *args, **kwargs)
+        def __init__(self, *args, **kwargs):
+            kwargs['required'] = False
+            forms.DecimalField.__init__(self, *args, **kwargs)
+
+        def clean(self, value):
+            # Parent "clean" calls "DecimaField.to_python" which converts value to Decimal or None.
+            value = super(DecimalValue.field, self).clean(value)
+            if value == None:
+                return Decimal("0")
+            return Decimal(value)
 
     def to_python(self, value):
-        if value==NOTSET:
+        if value == NOTSET:
             return Decimal("0")
 
         try:
@@ -424,12 +449,19 @@ class DecimalValue(Value):
         else:
             return unicode(value)
 
-# DurationValue has a lot of duplication and ugliness because of issue #2443
-# Until DurationField is sorted out, this has to do some extra work
 class DurationValue(Value):
+    # DurationValue has a lot of duplication and ugliness because DurationField
+    # probably never will be accepted into Django code (issue #2443).
 
     class field(forms.CharField):
+
+        def __init__(self, *args, **kwargs):
+            kwargs['required'] = False
+            forms.CharField.__init__(self, *args, **kwargs)
+
         def clean(self, value):
+            if value == '':
+                value = 0
             try:
                 return datetime.timedelta(seconds=float(value))
             except (ValueError, TypeError):
@@ -464,7 +496,7 @@ class FloatValue(Value):
             forms.FloatField.__init__(self, *args, **kwargs)
 
     def to_python(self, value):
-        if value == NOTSET:
+        if value in (NOTSET, None) :
             value = 0
         return float(value)
 
@@ -482,7 +514,7 @@ class IntegerValue(Value):
             forms.IntegerField.__init__(self, *args, **kwargs)
 
     def to_python(self, value):
-        if value == NOTSET:
+        if value in (NOTSET, None):
             value = 0
         return int(value)
 
@@ -493,25 +525,48 @@ class IntegerValue(Value):
             return unicode(value)
 
 
+# Deprecated PercentValue does not work good and can not be fixed
+# without duplicating long modified parts of Django. #29
+# It is better to Replace PercentValue(...) by DecimalValue(... min_value=0, max_value=100, max_decimal_places=2)
+# and easily divide result value by 100 in the user application.
 class PercentValue(Value):
 
     class field(forms.DecimalField):
 
         def __init__(self, *args, **kwargs):
+            import warnings
+            warnings.warn(
+                "class livesettings.PercentValue is deprecated. It should be replaced in config.py by " \
+                "DecimalValue(... min_value=0, max_value=100) and the result divided by 100 in the app.",
+                DeprecationWarning
+            )
             kwargs['required'] = False
             forms.DecimalField.__init__(self, 100, 0, 5, 2, *args, **kwargs)
 
+        def clean(self, value):
+            if value == '':
+                value = 0
+            value = super(forms.DecimalField, self).clean(value)
+            try:
+                value = Decimal(value)
+            except:
+                raise forms.ValidationError('This value must be a decimal number.')
+            return unicode(Decimal(value)/100)
+        
         class widget(forms.TextInput):
-            def render(self, *args, **kwargs):
+            def render(self, name, value, attrs=None):
                 # Place a percent sign after a smaller text field
-                attrs = kwargs.pop('attrs', {})
+                try:
+                    value = unicode("%.2f" % (Decimal(value)*100))
+                except:
+                    value = "N/A"
                 attrs['size'] = attrs['max_length'] = 6
-                return forms.TextInput.render(self, attrs=attrs, *args, **kwargs) + '%'
+                return mark_safe(super(forms.TextInput, self).render(name, value, attrs) + '%')
 
     def to_python(self, value):
         if value == NOTSET:
             value = 0
-        return Decimal(value) / 100
+        return Decimal(value)
 
     def to_editor(self, value):
         if value == NOTSET:
@@ -524,6 +579,7 @@ class PositiveIntegerValue(IntegerValue):
     class field(forms.IntegerField):
 
         def __init__(self, *args, **kwargs):
+            kwargs['required'] = False
             kwargs['min_value'] = 0
             forms.IntegerField.__init__(self, *args, **kwargs)
 
@@ -542,6 +598,42 @@ class StringValue(Value):
 
     to_editor = to_python
 
+class PasswordValue(StringValue):
+    """
+    Configuration value of the type Password
+    Usage:
+        config_register(PasswordValue(group, key, description=None, help_text,... render_value=True))
+
+        render_value    Determines whether the widget will have a value filled in when the form is re-displayed (default is True).
+                        If render_value=False, a password can be also completely deleted by writing space to the field.
+    """
+    # class field is dynamically assigned to the instance as FieldRender or FieldNoRender
+    class FieldRender(forms.CharField):
+        render_value = True
+        def __init__(self, *args, **kwargs):
+            kwargs['required'] = False
+            kwargs['widget'] = forms.PasswordInput(render_value=self.render_value)
+            forms.CharField.__init__(self, *args, **kwargs)
+
+    class FieldNoRender(FieldRender):
+        render_value = False
+
+    def __init__(self, *args, **kwargs):
+        # prevent modifiyng of update_callback
+        save_update_callback = self.update_callback
+        setattr(self, 'field', kwargs.pop('render_value', True) and PasswordValue.FieldRender or PasswordValue.FieldNoRender)
+        super(PasswordValue, self).__init__(*args, **kwargs)
+        self.update_callback = save_update_callback
+
+    def update_callback(self, current_value, new_value):
+        # An old password can be deleted only by one space.
+        if not self.field.render_value:
+            if new_value == '':
+                return current_value
+            elif new_value == ' ':
+                return ''
+        return new_value
+
 class LongStringValue(Value):
 
     class field(forms.CharField):
@@ -619,12 +711,18 @@ class ModuleValue(Value):
             return load_module("%s.%s" % (value, module))
 
     def to_python(self, value):
-        if value == NOTSET:
-            v = {}
+        if value in (NOTSET, ''):
+            v = {}    # TODO this was probably not a good idea
         else:
-            v = load_module(value)
+            try:
+                v = load_module(value)
+            except ImportError:
+                v = ''
         return v
 
+    def get_db_prep_save(self, value):
+        return getattr(value, '__name__', '')
+
     def to_editor(self, value):
         if value == NOTSET:
             value = ""
